module Lightspeed
  module API
    module Helpers
      module Pagination
        def with_pages(limit:)
          limit ||= 100
          results = []
          offset = 0
          count = Float::INFINITY
          while offset < count
            response = yield(options_string(offset, limit))
            body = response.body
            raise_error(response) unless response.success?
            attributes = body.delete("@attributes")
            count = attributes["count"].to_i
            offset = attributes["offset"].to_i + limit
            results << body.values
          end
          results.flatten
        end

        private

        def options_string(offset, limit)
          "offset=#{offset}&limit=#{limit}"
        end

        def raise_error(response)
          raise Lightspeed::API::Error.new(
            message: response.body["message"],
            response: response,
          )
        end
      end
    end
  end
end
